import argparse

from trackio import show


def main():
    parser = argparse.ArgumentParser(description="Trackio CLI")
    subparsers = parser.add_subparsers(dest="command")

    ui_parser = subparsers.add_parser(
        "show", help="Show the Trackio dashboard UI for a project"
    )
    ui_parser.add_argument(
        "--project", required=False, help="Project name to show in the dashboard"
    )

    args = parser.parse_args()

    if args.command == "show":
        show(args.project)
    else:
        parser.print_help()


if __name__ == "__main__":
    main()



import random

from tqdm import tqdm

import trackio as wandb

project_id = random.randint(10000, 99999)

wandb.init(
    project=f"fake-training-{project_id}",
    name="test-run",
    config=dict(
        epochs=5,
        learning_rate=0.001,
        batch_size=32,
    ),
    space_id=f"abidlabs/trackio-{project_id}",
)

EPOCHS = 5
NUM_TRAIN_BATCHES = 100
NUM_VAL_BATCHES = 20

for epoch in range(EPOCHS):
    train_loss = 0
    train_accuracy = 0
    val_loss = 0
    val_accuracy = 0

    for _ in tqdm(range(NUM_TRAIN_BATCHES), desc=f"Epoch {epoch + 1} - Training"):
        loss = random.uniform(0.2, 1.0)
        accuracy = random.uniform(0.6, 0.95)
        train_loss += loss
        train_accuracy += accuracy

    for _ in tqdm(range(NUM_VAL_BATCHES), desc=f"Epoch {epoch + 1} - Validation"):
        loss = random.uniform(0.2, 0.9)
        accuracy = random.uniform(0.65, 0.98)
        val_loss += loss
        val_accuracy += accuracy

    train_loss /= NUM_TRAIN_BATCHES
    train_accuracy /= NUM_TRAIN_BATCHES
    val_loss /= NUM_VAL_BATCHES
    val_accuracy /= NUM_VAL_BATCHES

    wandb.log(
        {
            "epoch": epoch + 1,
            "train_loss": train_loss,
            "train_accuracy": train_accuracy,
            "val_loss": val_loss,
            "val_accuracy": val_accuracy,
        }
    )

wandb.finish()



import huggingface_hub
from gradio_client import Client

from trackio.utils import generate_readable_name


class Run:
    def __init__(
        self,
        project: str,
        client: Client,
        name: str | None = None,
        config: dict | None = None,
        dataset_id: str | None = None,
    ):
        self.project = project
        self.client = client
        self.name = name or generate_readable_name()
        self.config = config or {}
        self.dataset_id = dataset_id

    def log(self, metrics: dict):
        self.client.predict(
            api_name="/log",
            project=self.project,
            run=self.name,
            metrics=metrics,
            dataset_id=self.dataset_id,
            hf_token=huggingface_hub.utils.get_token(),
        )

    def finish(self):
        pass



from unittest.mock import MagicMock

import huggingface_hub

from trackio.run import Run


class DummyClient:
    def __init__(self):
        self.predict = MagicMock()


def test_run_log_calls_client():
    client = DummyClient()
    run = Run(project="proj", client=client, name="run1")
    metrics = {"x": 1}
    run.log(metrics)
    client.predict.assert_called_once_with(
        api_name="/log",
        project="proj",
        run="run1",
        metrics=metrics,
        dataset_id=None,
        hf_token=huggingface_hub.utils.get_token(),
    )
